import java.util.ArrayList;

import com.badlogic.gdx.Game;
import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input;
import com.badlogic.gdx.backends.lwjgl.LwjglApplication;
import com.badlogic.gdx.backends.lwjgl.LwjglApplicationConfiguration;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.graphics.OrthographicCamera;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer;
import com.badlogic.gdx.math.Vector2;
import com.badlogic.gdx.physics.box2d.Box2DDebugRenderer;
import com.badlogic.gdx.physics.box2d.World;

public class GameLoop extends Game {
	Sonic s;
	ArrayList<Sonic> sonics = new ArrayList<Sonic>();
	InputMapper mapper;
	ArrayList<ArrayList<Integer>> map;

	static final int WIN_WIDTH = 600;
	static final int WIN_HEIGHT = 400;

	OrthographicCamera cam;
	World world = new World(new Vector2(0, -30), true);
	Box2DDebugRenderer boxDebug;

	@Override
	public void create() {
		boxDebug = new Box2DDebugRenderer();
		cam = new OrthographicCamera(WIN_WIDTH, WIN_HEIGHT);
		cam.position.set(cam.viewportWidth / 2f, cam.viewportHeight / 2f, 0);
		cam.update();

		map = LevelLoader.loadMap(Gdx.files.internal("data/map1.txt").path());
		mapper = new InputMapper();
		s = new Sonic(world, WIN_WIDTH / 2, WIN_HEIGHT / 2);
		renderMap();
	}

	@Override
	public void render() {
		cam.update();
		Gdx.gl.glClearColor(1, 1, 1, 1);
		Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);

		boxDebug.render(world, cam.combined);

		world.step(1 / 60f, 6, 2);

		s.step();
		checkInput();
		
		for(Sonic thisS : sonics){
			thisS.step();
		}
	}

	private void renderMap() {
		ShapeRenderer sr = new ShapeRenderer();
		sr.setAutoShapeType(true);

		int mh = map.size();
		int mw = map.get(0).size();

		int tw = WIN_WIDTH / mw;
		int th = WIN_HEIGHT / mh;

		sr.begin();
		sr.setColor(1, 0, 0, 1);
		for (int i = 0; i < mh; i++) {
			for (int j = 0; j < mw; j++) {
				if (map.get(i).get(j) == 1) {
					int thisX = j * tw + tw / 2;
					int thisY = i * th + th / 2;
					new Cell(world, thisX, thisY, tw / 2, th / 2);
					// sr.rect(j * tw, i * th, tw, th);
				}
			}
		}
		sr.end();

	}

	public static void main(String[] args) {
		LwjglApplicationConfiguration config = new LwjglApplicationConfiguration();
		config.width = WIN_WIDTH;
		config.height = WIN_HEIGHT;
		new LwjglApplication(new GameLoop(), config);
	}

	private void checkInput() {
		if (mapper.inKeyMap(Input.Keys.ESCAPE)) {
			System.exit(0);
		}
		if (mapper.inKeyMap(Input.Keys.W)) {
			s.move(0, 5);
		}
		if (mapper.inKeyMap(Input.Keys.A)) {
			s.move(-5, 0);
		}
		if (mapper.inKeyMap(Input.Keys.S)) {
			s.move(0, -5);
		}
		if (mapper.inKeyMap(Input.Keys.D)) {
			s.move(5, 0);
		}
		if (mapper.inKeyMap(-1)) {
			System.out.println("clicked");
			mapper.input.put(-1, false);
			newSonic(mapper.x, mapper.y);
		}
	}

	private void newSonic(int x, int y) {
		sonics.add(new Sonic(world, x, WIN_HEIGHT-y));
	}
}
