import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureRegion;
import com.badlogic.gdx.physics.box2d.Body;
import com.badlogic.gdx.physics.box2d.BodyDef;
import com.badlogic.gdx.physics.box2d.BodyDef.BodyType;
import com.badlogic.gdx.physics.box2d.Fixture;
import com.badlogic.gdx.physics.box2d.FixtureDef;
import com.badlogic.gdx.physics.box2d.PolygonShape;
import com.badlogic.gdx.physics.box2d.World;

public class Sonic {
	public static final int FRAMES = 4;
	public static final int FW = 33;
	public static final int FH = 36;

	Body body;
	BodyDef bodyDef;
	Fixture fixture;
	
	SpriteBatch sp;
	Texture tx;
	int x, y;
	int frame;
	TextureRegion[] frames;
	Sonic(World world, int x, int y){
		tx = new Texture(Gdx.files.internal("data/sonic.png"));
		sp = new SpriteBatch();
		this.x = x;
		this.y = y;
		frame = 0;
		frames = new TextureRegion[Sonic.FRAMES];
		for(int i = 0; i < Sonic.FRAMES; i++){
			frames[i] = new TextureRegion(tx, Sonic.FW * i, 0, Sonic.FW, Sonic.FH);
		}
		
		
		bodyDef = new BodyDef();
		// We set our body to dynamic, for something like ground which doesn't move we would set it to StaticBody
		bodyDef.type = BodyType.DynamicBody;
		// Set our body's starting position in the world
		bodyDef.position.set(x, y);

		// Create our body in the world using our body definition
		body = world.createBody(bodyDef);

		PolygonShape collisionBox = new PolygonShape();
		collisionBox.setAsBox(FW/2, FH/2);

		// Create a fixture definition to apply our shape to
		FixtureDef fixtureDef = new FixtureDef();
		fixtureDef.shape = collisionBox;
		fixtureDef.density = 2.5f; 
		fixtureDef.friction = 0.4f;
		fixtureDef.restitution = 0.1f; // Make it bounce a little bit

		// Create our fixture and attach it to the body
		fixture = body.createFixture(fixtureDef);
	}
	void step(){
		x = (int)body.getPosition().x;
		y = (int)body.getPosition().y;

		sp.begin();
		sp.draw(frames[frame], x-FW/2, y-FH/2);
		sp.end();
		frame = (frame + 1) % Sonic.FRAMES;
	}
	void move(int dx, int dy){
		x += dx;
		y += dy;
	}
}
